@@ -17,7 +17,6 @@ import logging
 from keystoneauth1 import identity
 from keystoneauth1 import session
 from keystoneclient import discover
-import six
 
 from monasca_agent.common import singleton
 from monasca_agent import version as ma_version
@@ -58,7 +57,7 @@ def get_session(**kwargs):
     - using **Keystone v3** be careful with the scope of authentication.
       For more details about scopes refer to identity_tokens_ and v3_identity_
 
-    .. _v3_api: https://developer.openstack.org/api-ref/identity/v3/index.html?expanded=token-authe
+    .. _v3_api: https://docs.openstack.org/api-ref/identity/v3/index.html?expanded=token-authe
     ntication-with-scoped-authorization-detail
     .. _identity_tokens: https://docs.openstack.org/admin-guide/identity-tokens.html
 
@@ -244,8 +243,7 @@ def get_args(config):
     return clean_args
 
 
-@six.add_metaclass(singleton.Singleton)
-class Keystone(object):
+class Keystone(object, metaclass=singleton.Singleton):
 
     def __init__(self, config):
         self._config = get_args(config)
