@@ -15,8 +15,7 @@
 
 import logging
 import os
-
-from six.moves import urllib
+import urllib
 
 import monasca_setup.agent_config
 import monasca_setup.detection
