@@ -1,4 +1,6 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# Copyright 2021 FUJITSU LIMITED
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -28,9 +30,10 @@ class Keystone(monasca_setup.detection.ServicePlugin):
             'service_name': 'identity-service',
             'process_names': ['keystone-admin',
                               'keystone-main',
-                              'keystone-all'],
+                              'keystone-all',
+                              'keystone'],
             'service_api_url': 'http://localhost:35357/v3',
-            'search_pattern': '.*v3\..*'
+            'search_pattern': r'.*v3\..*'
         }
 
         super(Keystone, self).__init__(service_params)
