@@ -11,7 +11,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 import unittest
 
 from monasca_agent.collector.checks_d.kubernetes_api import KubernetesAPI
